@@ -1,6 +1,6 @@
 package Task::CPANPLUS::Metabase;
 BEGIN {
-  $Task::CPANPLUS::Metabase::VERSION = '0.02';
+  $Task::CPANPLUS::Metabase::VERSION = '0.04';
 }
 
 # ABSTRACT: Install everything for CPANPLUS to use Metabase
@@ -20,13 +20,13 @@ Task::CPANPLUS::Metabase - Install everything for CPANPLUS to use Metabase
 
 =head1 VERSION
 
-version 0.02
+version 0.04
 
 =head1 SYNOPSIS
 
   cpanp -i Task::CPANPLUS::Metabase
 
-  metabase-cpanp
+  metabase_cpanp
 
 =head1 DESCRIPTION
 
@@ -34,7 +34,7 @@ Task::CPANPLUS::Metabase is a L<Task> module that installs the modules
 required for using L<Test::Reporter::Transport::Metabase> with L<CPANPLUS>
 for submitting CPAN test reports to the L<Metabase>.
 
-Also included is L<metabase-cpanp> script which will generate an appropriate
+Also included is L<metabase_cpanp> script which will generate an appropriate
 id file and configure L<CPANPLUS> for submitting CPAN test reports.
 
 =head1 AUTHOR
